@@ -103,7 +103,22 @@ sub run {
                     File::Spec->join( $self->runtime_path, $type ));
         }
         else {
-            die "Can't script type not found.";
+            print <<END;
+Error: Script type not found.
+File Stored at: @{[ $self->target ]}
+
+We can't get the script type of this plugin "@{[ $self->package ]}".
+Please infom the plugin author to add a script type tag like this:
+
+    " ScriptType: [script type]
+
+For example:
+    
+    " ScriptType: ftplugin/perl
+
+Thanks.
+END
+            exit;
             # XXX: more useful message.
         }
     }
@@ -159,6 +174,14 @@ sub inspect_text_content {
         $arg->{deps} = \@deps;
     }
 
+    if( $content =~ m{^"\s*tutorial:\s*(.*)}im ) {
+        $arg->{tutorial} = $1;  # URL
+    }
+
+    if( $content =~ m{^"\s*repository:\s*(.*)}im ) {
+        $arg->{repository} = $1;
+    }
+
     if( $content =~ m{^"\s*(?:script\s*)?version:\s*([.0-9]+)}im ) {
         $arg->{version} = $1;
     }
